
The analemma is the beautiful double-loop path traced by the shadow on a sundial (or the sun in the sky) when observed at the same time each day throughout one year. This package calculates and plots the analemma for all types of sundial anywhere on earth, or any planet.

 * Homepage: https://russellgoyder.github.io/sundial-latex/
 * Documentation | https://analemma.readthedocs.io/en/stable/
 * Repository | https://github.com/russellgoyder/sundial
 * Issue Tracker | https://github.com/russellgoyder/sundial/issues
